# 2023-05-19 - GaugeAdder V4

Deployment of the new `GaugeAdder`, a helper contract which helps prevent some forms of improper configuration on the `GaugeController`.

This version supports adding dynamic gauge types, and allows only one factory per gauge type at a time.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`GaugeAdder` artifact](./artifact/GaugeAdder.json)
- [Previous `GaugeAdder` deployment](../deprecated/20230109-gauge-adder-v3)
